@@ -1,4 +1,4 @@
-from typing import List, Dict, Optional
+from typing import List, Dict, Optional, Tuple
 import time, json, traceback
 
 from selenium_firefox.firefox import Firefox, By, Keys
@@ -107,7 +107,7 @@ class Pinterest:
 
             return False
 
-    def repin(self, pin_id: str, board_name: str, needs_repin_id: bool=False) -> (bool, Optional[str]):
+    def repin(self, pin_id: str, board_name: str, needs_repin_id: bool=False) -> Tuple[bool, Optional[str]]:
         try:
             self.browser.get(UrlCreator.pin_url(pin_id))
             rand.sleep(0.7, 1.2)
@@ -198,7 +198,7 @@ class Pinterest:
         ignored_users: List[str],
         number_of_users_to_follow, 
         full_board_url: str = None
-    ) -> Optional[(List[str], List[str])]:
+    ) -> Optional[Tuple[List[str], List[str]]]:
         try:
             if full_board_url is not None:
                 self.browser.get(full_board_url)
@@ -255,7 +255,7 @@ class Pinterest:
 
             return None
 
-    def search_pinterest_boards(self, search_term: str, number_of_boards_to_get: int=35) -> Optional[List[(str, str)]]:
+    def search_pinterest_boards(self, search_term: str, number_of_boards_to_get: int=35) -> Optional[List[Tuple[str, str]]]:
         try:
             self.browser.get(UrlCreator.search_board_url(search_term))
             rand.sleep(1, 1.5)
